# -*- coding: ISO-8859-1 -*-
# Copyright (C) 2004-2005 Luis Belmar-Letelier <luis@itaapy.com>
#               2005 Alexandre Fernandez <alex@itaapy.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.


# Import from itools
from itools.zope import get_context

# Import from ikaaro
from Products.ikaaro.Root import Root as ikaaroRoot
from Products.ikaaro.Folder import Folder as ikaaroFolder
from Products.ikaaro.Text import HTML as ikaaroHTML
from Products.ikaaro.Handler import Handler as ikaaroHandler
from Products.ikaaro.File import File as ikaaroFile
from Products.ikaaro.utils import comeback 
from Products.ikaaro import ui



class Base(object):

    view__label__ = u'Preview'
    view__access__ = True
    def view(self):
        """ 
        The main backoffice view method, used to show folders and documents 
        """
        namespace = {}
        here = get_context().handler
        handlers = here.get_handlers(format='Document')
        documents = [{'url': '%s/;view' % here.get_pathto(h),
                      'name': h.title or h.name} for h in handlers]
        namespace['docs'] = documents

        handlers = here.get_handlers(format='PortalFolder')
        folders = [{'url': '%s/;view' % here.get_pathto(h),
                    'name': h.title or h.name} for h in handlers] 
        namespace['folders'] = folders
        namespace['title'] = self.title or self.name

        handler = ui.get_handler('frontoffice1/Base_view.xml')
        return handler.stl(namespace)


    def get_rank(self):
        rank = self.get_property('port:rank')
        return str(rank)

    rank = property(get_rank, None, None, '')


    ########################################################################
    # Metadata

    edit_metadata__access__ = True
    def edit_metadata(self, **kw):
        context = get_context()
        root = context.root

        self.set_property('dc:title', kw.get('dc:title'))
        self.set_property('port:title', kw.get('port:title'))
        self.set_property('port:description', kw.get('port:description'))
        self.set_property('port:rank', kw.get('port:rank'))

        expiration_date = kw.get('port:expiration_date')
        self.set_property('port:expiration_date', expiration_date) 

        # Reindex
        root.reindex_handler(self)

        message = 'Metadata changed.'
        comeback('edit_metadata_form', message)


    edit_metadata_form__access__ = True 
    edit_metadata_form__label__ = 'port Metadata'
    def edit_metadata_form(self):
        namespace = {}

        # Title
        namespace['title'] = self.get_property('dc:title')

        # expiration_date 
        exp_date = self.get_property('port:expiration_date')
        namespace['expiration_date'] = exp_date.strftime('%Y-%m-%d %H:%M')

        # Title port
        namespace['port_title'] = self.get_property('port:title')

        # Rank port
        namespace['port_rank'] = self.get_property('port:rank')

        # Description
        namespace['description'] = self.get_property('port:description')

        handler = ui.get_handler('frontoffice1/Metadata_edit.xml')
        return handler.stl(namespace)


    switch_skin__label__ = u"Switch skin"
    switch_skin__access__ = True
    def switch_skin(self):
        context = get_context()
        request, response = context.request, context.response
        
        actual_skin = 'surf'
        if 'skin' in context.session:
            actual_skin = context.session['skin']

        # switch 'surf' and 'frontoffice1' skins
        if not actual_skin == 'surf':
            switched_skin = 'surf'
        else:
            switched_skin = 'frontoffice1'

        # save the the new skin in the session
        context.session['skin'] = switched_skin 

        # come back to a corect url after switch 
        url = request.referer
        if switched_skin == 'frontoffice1':
            url = ';view'
        response.redirect(url)



class Root(Base, ikaaroRoot):

    class_id = 'Portal'
    class_title = u'Portal four'
    class_version = '20041106'

    _catalog_fields = ikaaroRoot._catalog_fields \
                      + [('rank', 'keyword', False, True)]


    def get_skin_name(self):
        context = get_context()
        default_skin = ikaaroRoot.get_skin_name(self)
        return context.session.get('skin', default_skin)


    def get_document_types(self):
        types = ikaaroRoot.get_document_types(self)
        return types + [PortalFolder]

ikaaroRoot.register_handler_class(Root)



class PortalFolder(Base, ikaaroFolder):

    class_id = 'PortalFolder'
    class_title = u'Our Portal Folder'
    class_description = u'Here the description of our Portal Folder'
    class_version = '20050125'
    class_icon48 = 'frontoffice1/images/Folder48.png'
    class_icon16 = 'frontoffice1/images/Folder16.png'


    def get_document_types(self):
         return [Document, PortalFolder, ikaaroFile]


    def get_views(self):
        views = ikaaroFolder.get_views(self)
        views += ['view', 'list_view', 'switch_skin']
        return views

    def _browse_namespace(self, object):
        root = get_context().root
        abspath = object['abspath']

        handler = root.get_handler(abspath)
        # get_property gave a property even if no such a port:rank in 
        # the handler
        object['rank'] = handler.get_property('port:rank')
        object['rank_url'] = '%s/;edit_metadata_form' % object['name']
        object['port_description'] = handler.get_property('port:description')


    list_view__label__ = u'Portal list view'
    list_view__access__ = True
    def list_view(self):
        namespace = self.browse_namespace(16)
        handler = ui.get_handler('frontoffice1/PortalFolder_list_view.xml')
        return handler.stl(namespace)

ikaaroFolder.register_handler_class(PortalFolder)



class Document(Base, ikaaroHTML):

    class_id = 'Document'
    class_title = u'Our Document'
    class_description = u'Here the description of our special Document Type'
    class_version = '20041106'
    class_icon48 = 'frontoffice1/images/Document48.png'
    class_icon16 = 'frontoffice1/images/Document16.png'


    view__label__ = u'Preview'
    view__access__ = True
    def view(self):
        namespace = {}
        namespace['title'] = self.title or self.name
        namespace['body'] = self.preview()

        handler = ui.get_handler('frontoffice1/Document_view.xml')
        return handler.stl(namespace)


    def get_views(self):
        views = ikaaroHTML.get_views(self)
        views += ['view', 'switch_skin']
        return views

ikaaroHTML.register_handler_class(Document)
